#!/usr/bin/env python3

"""Create and email a list of new items

Author: Gem Stone-Logan
Contact Info: gem.stone-logan@mountainview.gov or gemstonelogan@gmail.com
"""

import psycopg2
import xlsxwriter

#Connecting to Sierra PostgreSQL database
conn = psycopg2.connect("dbname='iug' user='iuguser' host='localhost' port='1032' password='iugprog' sslmode='require'")

#Opening a session and querying the database for weekly new items
cursor = conn.cursor()
cursor.execute(open("WeeklyNewItemsRev.sql","r").read())
#For now, just storing the data in a variable. We'll use it later.
rows = cursor.fetchall()
conn.close()

#Creating the Excel file for staff
workbook = xlsxwriter.Workbook("WeeklyNewItem.xlsx")
worksheet = workbook.add_worksheet()


#Formatting our Excel worksheet
worksheet.set_landscape()
worksheet.hide_gridlines(0)

#Formatting Cells
eformat= workbook.add_format({'text_wrap': True, 'valign': 'top'})
eformatlabel= workbook.add_format({'text_wrap': True, 'valign': 'top', 'bold': True})

# Setting the column widths
worksheet.set_column(0,0,10.29)
worksheet.set_column(1,1,6.29)
worksheet.set_column(2,2,12.71)
worksheet.set_column(3,3,16.57)
worksheet.set_column(4,4,24.71)
worksheet.set_column(5,5,11.14)
worksheet.set_column(6,6,18.47)
worksheet.set_column(7,7,4.5)
worksheet.set_column(8,8,4.5)
worksheet.set_column(9,9,4.5)

#Inserting a header
worksheet.set_header('&CWeekly New List')

# Adding column labels
worksheet.write(0,0,'Bib Record#', eformatlabel)
worksheet.write(0,1,'Location', eformatlabel)
worksheet.write(0,2,'Call#', eformatlabel)
worksheet.write(0,3,'Author', eformatlabel)
worksheet.write(0,4,'Title', eformatlabel)
worksheet.write(0,5,'Barcode', eformatlabel)
worksheet.write(0,6,'Series', eformatlabel)
worksheet.write(0,7,'Item Count', eformatlabel)
worksheet.write(0,8,'Order Count', eformatlabel)
worksheet.write(0,9,'Hold Count', eformatlabel)

# Writing the report for staff to the Excel worksheet
for rownum, row in enumerate(rows):
    worksheet.write(rownum+1,0,row[0], eformat)
    worksheet.write(rownum+1,1,row[1], eformat)
    worksheet.write(rownum+1,2,row[2], eformat)
    worksheet.write(rownum+1,3,row[3], eformat)
    worksheet.write(rownum+1,4,row[4], eformat)
    worksheet.write(rownum+1,5,row[5], eformat)
    worksheet.write(rownum+1,6,row[6], eformat)
    worksheet.write(rownum+1,7,row[7], eformat)
    worksheet.write(rownum+1,8,row[8], eformat)
    worksheet.write(rownum+1,9,row[9], eformat)

workbook.close()


