#!/usr/bin/env python3

"""Create and email a list of new items

Author: Gem Stone-Logan
Contact Info: gem.stone-logan@mountainview.gov or gemstonelogan@gmail.com
"""

import psycopg2
import xlsxwriter
import smtplib
from email.mime.multipart import MIMEMultipart
from email.mime.base import MIMEBase
from email.mime.text import MIMEText
from email.utils import formatdate
from email import encoders

#Name of Excel File
excelfile =  'WeeklyNewItem.xlsx'

# These are variables for the email that will be sent.
# Make sure to use your own library's email server (emaihost)
emailhost = ''
emailport = '25'
emailsubject = 'Weekly New Report'
emailmessage = '''***This is an automated email***


The weekly new report has been attached. Please take a look and let the Technology Librarian know if there are any questions about it.'''
# Enter your own email information
emailfrom= ''
# emailto can send to multiple addresses by separating emails with commas
emailto = ['','']


#Connecting to Sierra PostgreSQL database
try:
    conn = psycopg2.connect("dbname='iug' user='iuguser' host='localhost' port='1032' password='iugprog' sslmode='require'")
except psycopg2.Error as e:
    print ("Unable to connect to database: " + str(e))

#Opening a session and querying the database for weekly new items
cursor = conn.cursor()
cursor.execute(open("WeeklyNewItemsRev.sql","r").read())
#For now, just storing the data in a variable. We'll use it later.
rows = cursor.fetchall()
conn.close()

#Creating the Excel file for staff
workbook = xlsxwriter.Workbook(excelfile)
worksheet = workbook.add_worksheet()


#Formatting our Excel worksheet
worksheet.set_landscape()
worksheet.hide_gridlines(0)

#Formatting Cells
eformat= workbook.add_format({'text_wrap': True, 'valign': 'top'})
eformatlabel= workbook.add_format({'text_wrap': True, 'valign': 'top', 'bold': True})

# Setting the column widths
worksheet.set_column(0,0,10.29)
worksheet.set_column(1,1,6.29)
worksheet.set_column(2,2,12.71)
worksheet.set_column(3,3,16.57)
worksheet.set_column(4,4,24.71)
worksheet.set_column(5,5,11.14)
worksheet.set_column(6,6,18.47)
worksheet.set_column(7,7,4.5)
worksheet.set_column(8,8,4.5)
worksheet.set_column(9,9,4.5)

#Inserting a header
worksheet.set_header('&CWeekly New List')

# Adding column labels
worksheet.write(0,0,'Bib Record#', eformatlabel)
worksheet.write(0,1,'Location', eformatlabel)
worksheet.write(0,2,'Call#', eformatlabel)
worksheet.write(0,3,'Author', eformatlabel)
worksheet.write(0,4,'Title', eformatlabel)
worksheet.write(0,5,'Barcode', eformatlabel)
worksheet.write(0,6,'Series', eformatlabel)
worksheet.write(0,7,'Item Count', eformatlabel)
worksheet.write(0,8,'Order Count', eformatlabel)
worksheet.write(0,9,'Hold Count', eformatlabel)

# Writing the report for staff to the Excel worksheet
for rownum, row in enumerate(rows):
    worksheet.write(rownum+1,0,row[0], eformat)
    worksheet.write(rownum+1,1,row[1], eformat)
    worksheet.write(rownum+1,2,row[2], eformat)
    worksheet.write(rownum+1,3,row[3], eformat)
    worksheet.write(rownum+1,4,row[4], eformat)
    worksheet.write(rownum+1,5,row[5], eformat)
    worksheet.write(rownum+1,6,row[6], eformat)
    worksheet.write(rownum+1,7,row[7], eformat)
    worksheet.write(rownum+1,8,row[8], eformat)
    worksheet.write(rownum+1,9,row[9], eformat)

workbook.close()

#Creating the email message
msg = MIMEMultipart()
msg['From'] = emailfrom
if type(emailto) is list:
    msg['To'] = ', '.join(emailto)
else:
    msg['To'] = emailto
msg['Date'] = formatdate(localtime = True)
msg['Subject'] = emailsubject
msg.attach (MIMEText(emailmessage))
part = MIMEBase('application', "octet-stream")
part.set_payload(open(excelfile,"rb").read())
encoders.encode_base64(part)
part.add_header('Content-Disposition','attachment; filename=%s' % excelfile)
msg.attach(part)

#Sending the email message
smtp = smtplib.SMTP(emailhost, emailport)
smtp.sendmail(emailfrom, emailto, msg.as_string())
smtp.quit()
